==> haskell-generics-sop-0.2.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.2.1.0
id: generics-sop-0.2.1.0-CBmuKl000aDETY5eYHsItd
key: generics-sop-0.2.1.0-CBmuKl000aDETY5eYHsItd
license: BSD3
maintainer: andres@well-typed.com
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
exposed: True
exposed-modules:
    Generics.SOP Generics.SOP.GGP Generics.SOP.TH Generics.SOP.Dict
    Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Instances
    Generics.SOP.Metadata Generics.SOP.NP Generics.SOP.NS
    Generics.SOP.Universe Generics.SOP.Sing
abi: 1708bba580e3c311ce8036b95a448a13
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/generics-sop-0.2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/generics-sop-0.2.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/generics-sop-0.2.1.0
hs-libraries: HSgenerics-sop-0.2.1.0-CBmuKl000aDETY5eYHsItd
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generics-sop-0.2.2.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.2.2.0
id: generics-sop-0.2.2.0-9w3u9oOObG6ENcL8IZfj8x
key: generics-sop-0.2.2.0-9w3u9oOObG6ENcL8IZfj8x
license: BSD3
maintainer: andres@well-typed.com
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
exposed: True
exposed-modules:
    Generics.SOP Generics.SOP.GGP Generics.SOP.TH Generics.SOP.Dict
    Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Instances
    Generics.SOP.Metadata Generics.SOP.NP Generics.SOP.NS
    Generics.SOP.Universe Generics.SOP.Sing
abi: 3d8a2524577aa3ce8531724464a2d6a9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/generics-sop-0.2.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/generics-sop-0.2.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/generics-sop-0.2.2.0
hs-libraries: HSgenerics-sop-0.2.2.0-9w3u9oOObG6ENcL8IZfj8x
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
